===============================================================================================
 passagemath: Linear Algebra with Givaro, fflas-ffpack, LinBox, IML, m4ri(e)
===============================================================================================

About SageMath
--------------

   "Creating a Viable Open Source Alternative to
    Magma, Maple, Mathematica, and MATLAB"

   Copyright (C) 2005-2024 The Sage Development Team

   https://www.sagemath.org

SageMath fully supports all major Linux distributions, recent versions of
macOS, and Windows (Windows Subsystem for Linux).

See https://doc.sagemath.org/html/en/installation/index.html
for general installation instructions.


About this pip-installable distribution
---------------------------------------

This pip-installable distribution ``passagemath-linbox``
provides modules that depend on the `LinBox suite <https://linalg.org/>`_
(Givaro, fflas-ffpack, LinBox), or on the libraries
`IML <https://cs.uwaterloo.ca/~astorjoh/iml.html>`_,
`m4ri <https://bitbucket.org/malb/m4ri/src/master/>`_,
`m4rie <https://bitbucket.org/malb/m4rie/src/master/>`_.
